-- main.lua for gallery mirror (modified)
function love.load()
	-- Notes:
	--	main screen size defaults to 800,600
	--	pixel effect applied to various portion for main screen (e.g. bottom half)
	--	tc values are fractions of screen (0.1,0.2,...0.5)
	--	subtractions for tc.x cause image to offset to left on mirror (bottom image)
	--	test conditions:
	--		tc.y < .5 address lower image (overwrites lower half of screen)
	--	subtraction from disty causes lower image to be inverted
	--	fade (0-1) - least intensity at lower values (0.25) - non-linear

	mirror = love.graphics.newPixelEffect [[
		extern float scale;
		extern float fade;
		extern float ymax;
		extern float xmax;
		extern float xmin;
		extern float ymin;
		vec4 effect(vec4 global_color, Image texture, vec2 tc, vec2 pc )
		{vec4 pixel;
			if (tc.y <= ymax)
				{if (tc.x <= xmax )
					{if (tc.x > xmin)
						{if (tc.y > ymin)
							{pixel = Texel(texture,
								vec2( tc.x-(tc.y-ymax)*scale/4, ymax + ( ymax-tc.y ) / scale ) );
								pixel.a = fade;}
							else { pixel = Texel(texture, vec2( tc.x, tc.y ) );}
							}
						else { pixel = Texel(texture, vec2( tc.x, tc.y ) );}
						}
					else { pixel = Texel(texture, vec2( tc.x, tc.y ) ); }
					}
				else { pixel = Texel(texture, vec2( tc.x, tc.y ) ); }
			return pixel;
			}
		]]

	gr, lk = love.graphics, love.keyboard
	x,  y  = 450, 75
	x2, y2 =  50, (600-375)/2
	x3, y3 = 370, (300-90)
	love.graphics.setBackgroundColor( 55,55,155 )
	mir={			-- location & dimentions of mirror
		xmin = 0.3,
		xmax = 0.7,
		ymin = 0.2,
		ymax = 0.5,
		fade = 0.2,
		scale= 1.0
		}
	for i,j in pairs(mir) do mirror:send(i,j) end

	img  = gr.newImage("hex.jpg")		-- right image
	img2 = gr.newImage("rainbow.jpg")	-- left image
	img3 = gr.newImage("lena.png")		-- center image

	lenaW	= img3:getWidth()/2
	lenaH	= img3:getHeight()
	ang		= 0							-- starting lena rotation
	canvas = love.graphics.newCanvas()
	function loadCanvas()
		canvas:clear()
		gr.setCanvas( canvas )
			gr.draw( img,  x,  y,  0, 0.75, 0.75 )-- 50% image size
			gr.draw( img2, x2, y2, 0, 0.5, 0.5 )
			gr.draw( img3, x3, y3, ang, 1, 1, lenaW, lenaH - 50 )
			gr.setCanvas()
			end
	end

function love.update( dt )
	step = 200 * dt		-- sensitivity of keyboard response
	local found
	if lk.isDown("left")	then x=x-step x2=x2-step x3=x3-step end
	if lk.isDown("right")	then x=x+step x2=x2+step x3=x3+step end
	if lk.isDown("up")		then y=y-step y2=y2-step y3=y3-step end
	if lk.isDown("down")	then y=y+step y2=y2+step y3=y3+step end
	if lk.isDown( 'a'  )	then mir.scale = mir.scale +0.01 mirror:send('scale', mir.scale ) end
	if lk.isDown( 's'  )	then mir.scale = mir.scale -0.01 mirror:send('scale', mir.scale ) end
	ang = ang + 0.01
	end

function love.draw()
	loadCanvas()
	gr.setPixelEffect(mirror)
	gr.draw(canvas)				-- pixel effect applied to entire canvas
	gr.setPixelEffect()			-- (but effect limited to mirror dimentions)
	gr.setColor(255,55,55)
	gr.rectangle('line',mir.xmin*800,mir.ymax*600,800*(mir.xmax-mir.xmin),600*(mir.ymax-mir.ymin))
	gr.setColor(255,255,255)
	end

function love.keypressed(key)  -- one operation per key press
	if key == 'escape'	then love.event.push('quit')		end
	if key == 'z'		then mir.fade = mir.fade - 0.05 mirror:send('fade', mir.fade ) end
	if key == 'x'		then mir.fade = mir.fade + 0.05 mirror:send('fade', mir.fade ) end
	end
